SLYP
====

Stephen Lints Your Python

An opinionated linter and fixer.

The source code is hosted in `a GitHub repo
<https://github.com/sirosen/slyp/>`_, and bugs and
features are tracked in the associated `issue tracker
<https://github.com/sirosen/slyp/issues/>`_.

.. toctree::
    :maxdepth: 2
    :caption: Contents:

    usage
    linter_rules
    fixer_rules

.. toctree::
    :maxdepth: 1
    :caption: Change History:

    changelog
